"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = void 0;
const errors_1 = require("./errors");
const fs_extra_1 = __importDefault(require("fs-extra"));
function getConfig() {
    return __awaiter(this, void 0, void 0, function* () {
        const { allowIntrospection, allowedOrigins, allowListPath, apiPort, cacheEnabled, genesisFileByron, genesisFileShelley, hasuraUri, listenAddress, postgresDb, postgresDbFile, postgresHost, postgresPassword, postgresPasswordFile, postgresPort, postgresUser, postgresUserFile, prometheusMetrics, queryDepthLimit, tracing } = filterAndTypecastEnvs(process.env);
        if (!hasuraUri && !genesisFileShelley) {
            throw new errors_1.MissingConfig(`You have not provided configuration to load an API segment. Either set HASURA_URI or 
      GENESIS_FILE_SHELLEY and GENESIS_FILE_SHELLEY`);
        }
        if (!postgresDbFile && !postgresDb) {
            throw new errors_1.MissingConfig('POSTGRES_DB_FILE or POSTGRES_DB env not set');
        }
        if (!postgresHost) {
            throw new errors_1.MissingConfig('POSTGRES_HOST env not set');
        }
        if (!postgresPasswordFile && !postgresPassword) {
            throw new errors_1.MissingConfig('POSTGRES_PASSWORD_FILE or POSTGRES_PASSWORD env not set');
        }
        if (!postgresPort) {
            throw new errors_1.MissingConfig('POSTGRES_PORT env not set');
        }
        if (!postgresUserFile && !postgresUser) {
            throw new errors_1.MissingConfig('POSTGRES_USER_FILE or POSTGRES_USER env not set');
        }
        let db;
        try {
            db = {
                database: postgresDb || (yield fs_extra_1.default.readFile(postgresDbFile, 'utf8')).toString(),
                host: postgresHost,
                password: postgresPassword || (yield fs_extra_1.default.readFile(postgresPasswordFile, 'utf8')).toString(),
                port: postgresPort,
                user: postgresUser || (yield fs_extra_1.default.readFile(postgresUserFile, 'utf8')).toString()
            };
        }
        catch (error) {
            throw new errors_1.MissingConfig('Database configuration cannot be read');
        }
        return {
            allowIntrospection: (process.env.NODE_ENV === 'production' && allowIntrospection) ||
                (process.env.NODE_ENV !== 'production' && allowIntrospection !== false),
            allowedOrigins: allowedOrigins || true,
            allowListPath,
            apiPort: apiPort || 3100,
            cacheEnabled: cacheEnabled || false,
            db,
            genesisFileByron,
            genesisFileShelley,
            hasuraUri,
            listenAddress: listenAddress || '0.0.0.0',
            prometheusMetrics,
            queryDepthLimit: queryDepthLimit || 10,
            tracing
        };
    });
}
exports.getConfig = getConfig;
function filterAndTypecastEnvs(env) {
    const { ALLOW_INTROSPECTION, ALLOWED_ORIGINS, ALLOW_LIST_PATH, API_PORT, CACHE_ENABLED, GENESIS_FILE_BYRON, GENESIS_FILE_SHELLEY, HASURA_URI, LISTEN_ADDRESS, POSTGRES_DB, POSTGRES_DB_FILE, POSTGRES_HOST, POSTGRES_PASSWORD, POSTGRES_PASSWORD_FILE, POSTGRES_PORT, POSTGRES_USER, POSTGRES_USER_FILE, PROMETHEUS_METRICS, QUERY_DEPTH_LIMIT, TRACING, WHITELIST_PATH } = env;
    if (WHITELIST_PATH) {
        console.warn(`WHITELIST_PATH is deprecated and will be removed in 3.0.0.
    Please update your configuration to use ALLOW_LIST_PATH instead.`);
    }
    return {
        allowIntrospection: ALLOW_INTROSPECTION === 'true',
        allowedOrigins: ALLOWED_ORIGINS,
        allowListPath: ALLOW_LIST_PATH || WHITELIST_PATH,
        apiPort: Number(API_PORT),
        cacheEnabled: CACHE_ENABLED === 'true',
        genesisFileByron: GENESIS_FILE_BYRON,
        genesisFileShelley: GENESIS_FILE_SHELLEY,
        hasuraUri: HASURA_URI,
        listenAddress: LISTEN_ADDRESS,
        postgresDb: POSTGRES_DB,
        postgresDbFile: POSTGRES_DB_FILE,
        postgresHost: POSTGRES_HOST,
        postgresPassword: POSTGRES_PASSWORD,
        postgresPasswordFile: POSTGRES_PASSWORD_FILE,
        postgresPort: Number(POSTGRES_PORT),
        postgresUser: POSTGRES_USER,
        postgresUserFile: POSTGRES_USER_FILE,
        prometheusMetrics: PROMETHEUS_METRICS === 'true',
        queryDepthLimit: Number(QUERY_DEPTH_LIMIT),
        tracing: TRACING === 'true'
    };
}
//# sourceMappingURL=config.js.map